# -*- coding: utf-8 -*-
from breq import Breq


class Reddit(Breq):

    def set_next(self):
        self.payload['after'] = self.response_content['data']['after']

    def is_last(self):
        if not self.response_content['data']['after']:
            return True
        return False


# coding: utf-8
from breq import Breq

class Github(Breq):

    def set_next(self):
        if 'next' in self.response.links:
            self.request_uri = self.response.links['next']['url']

    def is_last(self):
        if 'last' in self.response.links:
            return False
        return True


# coding: utf-8
from breq import Breq

class Guardian(Breq):

    def set_next(self):
        self.payload['page'] = self.response_content['response']['currentPage'] + 1

    def is_last(self):
        if self.response_content['response']['currentPage'] == self.response_content['response']['pages']:
            return True
        return False


# coding: utf-8
from breq import Breq

class Wikipedia(Breq):

    def set_next(self):
        self.payload['rvcontinue'] = self.response_content['query-continue']['revisions']['rvcontinue']

    def is_last(self):
        if 'query-continue' in self.response_content:
            return False
        return True


# coding: utf-8
# Python class to browse through API requests
import json
import requests
import time
from abc import ABCMeta, abstractmethod


class Breq(object):

    __metaclass__ = ABCMeta

    @abstractmethod
    def set_next(self, response):
        pass

    @abstractmethod
    def is_last(self, response):
        pass

    def __init__(self, request_uri, payload=None, max_requests=None,
        timeout=None, headers=None):
        self.request_uri = request_uri
        self.max_requests = max_requests
        if payload is None:
            payload = {}
        self.payload = payload

        if headers is None:
            headers = {}
        self.headers = headers

        self.request_count = 0
        self.last = False
        self.timeout = timeout
        self.response = None

    def __iter__(self):
        return self

    def next(self):
        if self.last or (
            self.max_requests and self.request_count >= self.max_requests):
            raise StopIteration

        try:
            response = requests.get(self.request_uri, params=self.payload,
                headers=self.headers)
        except Exception as err:
            print('HTTP request exception: %s\n%r' % (self.request_uri, err))
            return

        if not response.ok:
            print('HTTP request not ok: %s' % response.url)
            return

        self.request_count += 1
        self.response = response
        self.response_content = json.loads(response.content)

        if self.is_last():
            self.last = True
        else:
            self.set_next()
            if self.timeout:
                time.sleep(self.timeout)

        return self.response_content


#!/usr/bin/env python
# coding: utf-8
from setuptools import setup, find_packages

with open('requirements.txt') as f:
    required = f.read().splitlines()

setup(
    name='breq',
    version='0.7',
    packages=find_packages(),
    include_package_data=True,
    install_requires=required,
    long_description=open('README.rst').read(),
    license='MIT',
    author='Ramiro Gómez',
    author_email='code@ramiro.org',
    description='Browse Web service requests.',
    classifiers=[
        "Development Status :: 4 - Beta",
        "Environment :: Console",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Operating System :: POSIX",
        "Programming Language :: Python",
        "Topic :: Communications",
        "Topic :: Text Processing",
    ]
)